==> uuu_imx8mm_som_6.6.23.zip: usr/src/debug/dx-rt-npu/1.7.1/pci_deepx/dx_dma.mod.c <==
#include <linux/module.h>
#define INCLUDE_VERMAGIC
#include <linux/build-salt.h>
#include <linux/elfnote-lto.h>
#include <linux/export-internal.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

#ifdef CONFIG_UNWINDER_ORC
#include <asm/orc_header.h>
ORC_HEADER;
#endif

BUILD_SALT;
BUILD_LTO_INFO;

MODULE_INFO(vermagic, VERMAGIC_STRING);
MODULE_INFO(name, KBUILD_MODNAME);

__visible struct module __this_module
__section(".gnu.linkonce.this_module") = {
	.name = KBUILD_MODNAME,
	.init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
	.exit = cleanup_module,
#endif
	.arch = MODULE_ARCH_INIT,
};

#ifdef CONFIG_RETPOLINE
MODULE_INFO(retpoline, "Y");
#endif

KSYMTAB_FUNC(dx_pcie_get_dev_num, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_download_region, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_download_size, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_booting_region, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_init_completed, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_set_init_completed, "_gpl", "");
KSYMTAB_FUNC(xpdev_create_interfaces, "_gpl", "");
KSYMTAB_FUNC(xpdev_release_interfaces, "_gpl", "");
KSYMTAB_FUNC(dx_cdev_init, "_gpl", "");
KSYMTAB_FUNC(dx_cdev_cleanup, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_driver_info, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt_clear, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt_event, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt_wakeup, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt_event_wakeup, "_gpl", "");
KSYMTAB_FUNC(dx_sgdma_write, "_gpl", "");
KSYMTAB_FUNC(dx_sgdma_read, "_gpl", "");
KSYMTAB_FUNC(dx_sgdma_init, "_gpl", "");
KSYMTAB_FUNC(dx_sgdma_deinit, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_message_area, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_log_area, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_dl_area, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_request_queue, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_clear_response_queue, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_is_response_queue_empty, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_dequeue_response, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_enqueue_event_response, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_dequeue_event_response, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_clear_event_response, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_notify_msg_to_device, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_notify_req_to_device, "_gpl", "");

SYMBOL_CRC(dx_pcie_get_dev_num, 0x799c15a5, "_gpl");
SYMBOL_CRC(dx_pcie_get_download_region, 0x96375987, "_gpl");
SYMBOL_CRC(dx_pcie_get_download_size, 0x9f6c145f, "_gpl");
SYMBOL_CRC(dx_pcie_get_booting_region, 0xe1e7a493, "_gpl");
SYMBOL_CRC(dx_pcie_get_init_completed, 0x63be5207, "_gpl");
SYMBOL_CRC(dx_pcie_set_init_completed, 0x1ccbceca, "_gpl");
SYMBOL_CRC(xpdev_create_interfaces, 0x2df532f4, "_gpl");
SYMBOL_CRC(xpdev_release_interfaces, 0x09b28370, "_gpl");
SYMBOL_CRC(dx_cdev_init, 0x2af90a5b, "_gpl");
SYMBOL_CRC(dx_cdev_cleanup, 0xd3303193, "_gpl");
SYMBOL_CRC(dx_pcie_get_driver_info, 0xdf4fad68, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt, 0x645da062, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt_clear, 0x3d26254e, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt_event, 0x018e1731, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt_wakeup, 0xe4cb9af1, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt_event_wakeup, 0x98ff5b35, "_gpl");
SYMBOL_CRC(dx_sgdma_write, 0x4e28dccd, "_gpl");
SYMBOL_CRC(dx_sgdma_read, 0x9a3c9869, "_gpl");
SYMBOL_CRC(dx_sgdma_init, 0x9d9d70e6, "_gpl");
SYMBOL_CRC(dx_sgdma_deinit, 0xad0bf482, "_gpl");
SYMBOL_CRC(dx_pcie_get_message_area, 0xd545a0fc, "_gpl");
SYMBOL_CRC(dx_pcie_get_log_area, 0xe8765b54, "_gpl");
SYMBOL_CRC(dx_pcie_get_dl_area, 0xfda406b8, "_gpl");
SYMBOL_CRC(dx_pcie_get_request_queue, 0x9b9ef2b1, "_gpl");
SYMBOL_CRC(dx_pcie_clear_response_queue, 0x39e7916b, "_gpl");
SYMBOL_CRC(dx_pcie_is_response_queue_empty, 0x2699c5f1, "_gpl");
SYMBOL_CRC(dx_pcie_dequeue_response, 0x6106b455, "_gpl");
SYMBOL_CRC(dx_pcie_enqueue_event_response, 0x269ac578, "_gpl");
SYMBOL_CRC(dx_pcie_dequeue_event_response, 0x8be8ba0f, "_gpl");
SYMBOL_CRC(dx_pcie_clear_event_response, 0xb677b970, "_gpl");
SYMBOL_CRC(dx_pcie_notify_msg_to_device, 0x2ec2012f, "_gpl");
SYMBOL_CRC(dx_pcie_notify_req_to_device, 0x91193f38, "_gpl");

static const struct modversion_info ____versions[]
__used __section("__versions") = {
	{ 0xc1514a3b, "free_irq" },
	{ 0x49653ea2, "pcie_capability_read_word" },
	{ 0x58e739ab, "get_user_pages_fast" },
	{ 0x1f409d4e, "vchan_init" },
	{ 0x69e8c4e4, "flush_dcache_page" },
	{ 0x6e1503ea, "pci_find_ext_capability" },
	{ 0x3cda3de7, "simple_attr_open" },
	{ 0x142edddb, "param_ops_uint" },
	{ 0x433b632c, "debugfs_attr_write" },
	{ 0xd43887b, "devm_kmalloc" },
	{ 0x7f02188f, "__msecs_to_jiffies" },
	{ 0xe0804aaa, "dma_async_device_unregister" },
	{ 0xda53159c, "pci_alloc_irq_vectors" },
	{ 0x656e4a6e, "snprintf" },
	{ 0x43e8c187, "sched_set_normal" },
	{ 0xc8c85086, "sg_free_table" },
	{ 0xafa4afc, "debugfs_create_u16" },
	{ 0x92540fbf, "finish_wait" },
	{ 0xe32cadd2, "class_destroy" },
	{ 0x570ace15, "__pci_register_driver" },
	{ 0x4829a47e, "memcpy" },
	{ 0xaae53d06, "remap_pfn_range" },
	{ 0x37a0cba, "kfree" },
	{ 0xcaa15a5b, "pci_sriov_get_totalvfs" },
	{ 0x67a432ae, "dma_release_channel" },
	{ 0xe30339b7, "seq_lseek" },
	{ 0x8c26d495, "prepare_to_wait_event" },
	{ 0xe2964344, "__wake_up" },
	{ 0x7350d14a, "pci_irq_vector" },
	{ 0xb297c2ff, "kmem_cache_create" },
	{ 0x34db050b, "_raw_spin_lock_irqsave" },
	{ 0xba8fbd64, "_raw_spin_lock" },
	{ 0x5d112304, "__memcpy_fromio" },
	{ 0x9371f1c3, "pci_unregister_driver" },
	{ 0x3dfae3a5, "__dma_request_channel" },
	{ 0xa14ae809, "pci_read_config_dword" },
	{ 0x122c3a7e, "_printk" },
	{ 0x1000e51, "schedule" },
	{ 0x8ddd8aad, "schedule_timeout" },
	{ 0xf0fdf6cb, "__stack_chk_fail" },
	{ 0x6cbbfc54, "__arch_copy_to_user" },
	{ 0xb6a5811e, "pm_runtime_enable" },
	{ 0x599fb41c, "kvmalloc_node" },
	{ 0xb3f985a8, "sg_alloc_table" },
	{ 0x79891c66, "pci_find_capability" },
	{ 0xea3c74e, "tasklet_kill" },
	{ 0x57d20166, "debugfs_attr_read" },
	{ 0x9e8609be, "pcim_iomap_regions" },
	{ 0xfe487975, "init_wait_entry" },
	{ 0x5fec6bbc, "_dev_err" },
	{ 0x9be8e09f, "debugfs_create_file_unsafe" },
	{ 0x8c8569cb, "kstrtoint" },
	{ 0x92d5838e, "request_threaded_irq" },
	{ 0xf0b0ae7a, "simple_attr_release" },
	{ 0x66c37826, "irq_get_irq_data" },
	{ 0xfaaab126, "class_create" },
	{ 0x4dfa8d4b, "mutex_lock" },
	{ 0xafdb9160, "debugfs_remove" },
	{ 0x4a4a889, "pci_read_config_word" },
	{ 0x4ca58a, "seq_putc" },
	{ 0xa8b8c1b8, "vchan_tx_desc_free" },
	{ 0x9166fada, "strncpy" },
	{ 0x9d2ab8ac, "__tasklet_schedule" },
	{ 0x53a1e8d9, "_find_next_bit" },
	{ 0x18b48e28, "__memset_io" },
	{ 0xcefb0c9f, "__mutex_init" },
	{ 0x13640660, "get_cached_msi_msg" },
	{ 0xd35cce70, "_raw_spin_unlock_irqrestore" },
	{ 0xdcb764ad, "memset" },
	{ 0x4334ec64, "_dev_warn" },
	{ 0xdf49cf83, "pci_set_master" },
	{ 0xf04683ca, "debugfs_create_u32" },
	{ 0xd428442f, "dma_async_device_register" },
	{ 0xd9a5ea54, "__init_waitqueue_head" },
	{ 0xe2d5255a, "strcmp" },
	{ 0x15ba50a6, "jiffies" },
	{ 0x6e157f74, "dma_set_coherent_mask" },
	{ 0x4aff8bce, "seq_read" },
	{ 0x4afc4607, "debugfs_create_file" },
	{ 0x6091b333, "unregister_chrdev_region" },
	{ 0x8e30c021, "__pm_runtime_resume" },
	{ 0x3213f038, "mutex_unlock" },
	{ 0xeae3dfd6, "__const_udelay" },
	{ 0x9c0e42ce, "dma_async_tx_descriptor_init" },
	{ 0xfbe215e4, "sg_next" },
	{ 0x6bc16af3, "__folio_put" },
	{ 0x79e8c90f, "device_destroy" },
	{ 0xc071d811, "seq_printf" },
	{ 0xc3ce0c80, "pci_find_next_ext_capability" },
	{ 0xb9c091b, "pci_disable_sriov" },
	{ 0x12a4e128, "__arch_copy_from_user" },
	{ 0x778ef238, "set_page_dirty_lock" },
	{ 0x33c2a8b0, "single_release" },
	{ 0xa65c6def, "alt_cb_patch_nops" },
	{ 0x3d2ce023, "dma_set_mask" },
	{ 0xf3ebb86c, "sched_set_fifo" },
	{ 0x426e86a3, "dma_unmap_sg_attrs" },
	{ 0x9d2f58b9, "kmalloc_trace" },
	{ 0xd85aaf15, "pcim_iomap_table" },
	{ 0xa125ede7, "pci_read_config_byte" },
	{ 0x7aa1756e, "kvfree" },
	{ 0x8556b9c0, "single_open" },
	{ 0xb9bda96b, "pcim_enable_device" },
	{ 0x2ed86e57, "__pm_runtime_disable" },
	{ 0x92468b69, "debugfs_create_dir" },
	{ 0xb5b54b34, "_raw_spin_unlock" },
	{ 0x9bfdb105, "pci_free_irq_vectors" },
	{ 0x9010e87b, "pci_enable_sriov" },
	{ 0x8a0457e0, "__pm_runtime_idle" },
	{ 0x91fe42f5, "cdev_init" },
	{ 0x453d1f8e, "kmalloc_caches" },
	{ 0x9b89962f, "vchan_find_desc" },
	{ 0xa7622db5, "cdev_del" },
	{ 0x32e622b8, "kmem_cache_destroy" },
	{ 0x97c85d87, "vchan_tx_submit" },
	{ 0x3bdf71a9, "dma_map_sg_attrs" },
	{ 0x8e4e45ca, "module_layout" },
};

MODULE_INFO(depends, "");

MODULE_ALIAS("pci:v00001FF4d00000000sv*sd*bc*sc*i*");
MODULE_ALIAS("pci:v00001FF4d00000001sv*sd*bc*sc*i*");

MODULE_INFO(srcversion, "6ADE83EA0EC837B92FDA9AD");

==> uuu_imx8mm_som_6.12.34.zip: usr/src/debug/dx-rt-npu/1.7.1/pci_deepx/dx_dma.mod.c <==
#include <linux/module.h>
#include <linux/export-internal.h>
#include <linux/compiler.h>

MODULE_INFO(name, KBUILD_MODNAME);

__visible struct module __this_module
__section(".gnu.linkonce.this_module") = {
	.name = KBUILD_MODNAME,
	.init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
	.exit = cleanup_module,
#endif
	.arch = MODULE_ARCH_INIT,
};

KSYMTAB_FUNC(dx_pcie_get_dev_num, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_download_region, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_download_size, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_booting_region, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_init_completed, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_set_init_completed, "_gpl", "");
KSYMTAB_FUNC(xpdev_create_interfaces, "_gpl", "");
KSYMTAB_FUNC(xpdev_release_interfaces, "_gpl", "");
KSYMTAB_FUNC(dx_cdev_init, "_gpl", "");
KSYMTAB_FUNC(dx_cdev_cleanup, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_driver_info, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt_clear, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt_event, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt_wakeup, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_interrupt_event_wakeup, "_gpl", "");
KSYMTAB_FUNC(dx_sgdma_write, "_gpl", "");
KSYMTAB_FUNC(dx_sgdma_read, "_gpl", "");
KSYMTAB_FUNC(dx_sgdma_init, "_gpl", "");
KSYMTAB_FUNC(dx_sgdma_deinit, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_message_area, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_log_area, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_dl_area, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_get_request_queue, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_clear_response_queue, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_is_response_queue_empty, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_dequeue_response, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_enqueue_event_response, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_dequeue_event_response, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_clear_event_response, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_notify_msg_to_device, "_gpl", "");
KSYMTAB_FUNC(dx_pcie_notify_req_to_device, "_gpl", "");

SYMBOL_CRC(dx_pcie_get_dev_num, 0x799c15a5, "_gpl");
SYMBOL_CRC(dx_pcie_get_download_region, 0x96375987, "_gpl");
SYMBOL_CRC(dx_pcie_get_download_size, 0x9f6c145f, "_gpl");
SYMBOL_CRC(dx_pcie_get_booting_region, 0xe1e7a493, "_gpl");
SYMBOL_CRC(dx_pcie_get_init_completed, 0x63be5207, "_gpl");
SYMBOL_CRC(dx_pcie_set_init_completed, 0x1ccbceca, "_gpl");
SYMBOL_CRC(xpdev_create_interfaces, 0x46a2a87f, "_gpl");
SYMBOL_CRC(xpdev_release_interfaces, 0x0a50c3db, "_gpl");
SYMBOL_CRC(dx_cdev_init, 0x2af90a5b, "_gpl");
SYMBOL_CRC(dx_cdev_cleanup, 0xd3303193, "_gpl");
SYMBOL_CRC(dx_pcie_get_driver_info, 0xdf4fad68, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt, 0x645da062, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt_clear, 0x3d26254e, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt_event, 0x018e1731, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt_wakeup, 0xe4cb9af1, "_gpl");
SYMBOL_CRC(dx_pcie_interrupt_event_wakeup, 0x98ff5b35, "_gpl");
SYMBOL_CRC(dx_sgdma_write, 0x4e28dccd, "_gpl");
SYMBOL_CRC(dx_sgdma_read, 0x9a3c9869, "_gpl");
SYMBOL_CRC(dx_sgdma_init, 0x9d9d70e6, "_gpl");
SYMBOL_CRC(dx_sgdma_deinit, 0xad0bf482, "_gpl");
SYMBOL_CRC(dx_pcie_get_message_area, 0xd545a0fc, "_gpl");
SYMBOL_CRC(dx_pcie_get_log_area, 0xe8765b54, "_gpl");
SYMBOL_CRC(dx_pcie_get_dl_area, 0xfda406b8, "_gpl");
SYMBOL_CRC(dx_pcie_get_request_queue, 0x9b9ef2b1, "_gpl");
SYMBOL_CRC(dx_pcie_clear_response_queue, 0x39e7916b, "_gpl");
SYMBOL_CRC(dx_pcie_is_response_queue_empty, 0x2699c5f1, "_gpl");
SYMBOL_CRC(dx_pcie_dequeue_response, 0x6106b455, "_gpl");
SYMBOL_CRC(dx_pcie_enqueue_event_response, 0x269ac578, "_gpl");
SYMBOL_CRC(dx_pcie_dequeue_event_response, 0x8be8ba0f, "_gpl");
SYMBOL_CRC(dx_pcie_clear_event_response, 0xb677b970, "_gpl");
SYMBOL_CRC(dx_pcie_notify_msg_to_device, 0x2ec2012f, "_gpl");
SYMBOL_CRC(dx_pcie_notify_req_to_device, 0x91193f38, "_gpl");

static const struct modversion_info ____versions[]
__used __section("__versions") = {
	{ 0xc1514a3b, "free_irq" },
	{ 0x40bf659f, "pcie_capability_read_word" },
	{ 0xddad5cbd, "get_user_pages_fast" },
	{ 0x51283c9, "vchan_init" },
	{ 0x123dc9ea, "flush_dcache_page" },
	{ 0xd578f3b7, "pci_find_ext_capability" },
	{ 0x88b2d8b2, "simple_attr_open" },
	{ 0xa500bc78, "param_ops_uint" },
	{ 0x21a6c16f, "debugfs_attr_write" },
	{ 0x18d7061d, "devm_kmalloc" },
	{ 0x7f02188f, "__msecs_to_jiffies" },
	{ 0xda800f6b, "dma_async_device_unregister" },
	{ 0x78d80ed7, "pci_alloc_irq_vectors" },
	{ 0x656e4a6e, "snprintf" },
	{ 0xe36aa24f, "sched_set_normal" },
	{ 0xc8c85086, "sg_free_table" },
	{ 0xd5cb5572, "debugfs_create_u16" },
	{ 0x92540fbf, "finish_wait" },
	{ 0x3261c8f, "class_destroy" },
	{ 0x4c84996f, "__pci_register_driver" },
	{ 0x4829a47e, "memcpy" },
	{ 0xc0ab0ef4, "remap_pfn_range" },
	{ 0x37a0cba, "kfree" },
	{ 0x41daa89f, "pci_sriov_get_totalvfs" },
	{ 0x6d81fdad, "dma_release_channel" },
	{ 0xb9f3d8be, "seq_lseek" },
	{ 0x8c26d495, "prepare_to_wait_event" },
	{ 0xe2964344, "__wake_up" },
	{ 0x7c76e3e8, "pci_irq_vector" },
	{ 0x34db050b, "_raw_spin_lock_irqsave" },
	{ 0xba8fbd64, "_raw_spin_lock" },
	{ 0x5d112304, "__memcpy_fromio" },
	{ 0xc12839d7, "pci_unregister_driver" },
	{ 0x1a82a36c, "__dma_request_channel" },
	{ 0x69bb7dac, "pci_read_config_dword" },
	{ 0x92997ed8, "_printk" },
	{ 0x1000e51, "schedule" },
	{ 0x8ddd8aad, "schedule_timeout" },
	{ 0xf0fdf6cb, "__stack_chk_fail" },
	{ 0x6cbbfc54, "__arch_copy_to_user" },
	{ 0xb95421c8, "pm_runtime_enable" },
	{ 0xb3f985a8, "sg_alloc_table" },
	{ 0x41da8fee, "pci_find_capability" },
	{ 0xea3c74e, "tasklet_kill" },
	{ 0x262e7e32, "debugfs_attr_read" },
	{ 0xc9ee5946, "pcim_iomap_regions" },
	{ 0xfe487975, "init_wait_entry" },
	{ 0x750c138b, "_dev_err" },
	{ 0x99f1e921, "debugfs_create_file_unsafe" },
	{ 0x8c8569cb, "kstrtoint" },
	{ 0x92d5838e, "request_threaded_irq" },
	{ 0x3813f2d8, "simple_attr_release" },
	{ 0xfe15d4d1, "irq_get_irq_data" },
	{ 0xf83c89b8, "class_create" },
	{ 0x4dfa8d4b, "mutex_lock" },
	{ 0x76150dbc, "debugfs_remove" },
	{ 0xab6a5d2e, "pci_read_config_word" },
	{ 0x1e8b8843, "seq_putc" },
	{ 0x40ae7167, "vchan_tx_desc_free" },
	{ 0x9166fada, "strncpy" },
	{ 0x9d2ab8ac, "__tasklet_schedule" },
	{ 0x53a1e8d9, "_find_next_bit" },
	{ 0x18b48e28, "__memset_io" },
	{ 0xcefb0c9f, "__mutex_init" },
	{ 0x13640660, "get_cached_msi_msg" },
	{ 0xd35cce70, "_raw_spin_unlock_irqrestore" },
	{ 0xdcb764ad, "memset" },
	{ 0x8f58ec1, "_dev_warn" },
	{ 0xe2418ceb, "pci_set_master" },
	{ 0x195a6b5d, "debugfs_create_u32" },
	{ 0xe53feca1, "dma_async_device_register" },
	{ 0xd9a5ea54, "__init_waitqueue_head" },
	{ 0xbc666ff3, "__kmem_cache_create_args" },
	{ 0xe2d5255a, "strcmp" },
	{ 0x15ba50a6, "jiffies" },
	{ 0xf7431ce6, "dma_set_coherent_mask" },
	{ 0x84e7fabc, "seq_read" },
	{ 0x76dcbf9d, "debugfs_create_file" },
	{ 0x6091b333, "unregister_chrdev_region" },
	{ 0x8a508ef, "__pm_runtime_resume" },
	{ 0x3213f038, "mutex_unlock" },
	{ 0xeae3dfd6, "__const_udelay" },
	{ 0x82e1c1cc, "dma_async_tx_descriptor_init" },
	{ 0xfbe215e4, "sg_next" },
	{ 0x9e3874d, "__folio_put" },
	{ 0xd82c0a4f, "device_destroy" },
	{ 0xfbacb09, "__kmalloc_cache_noprof" },
	{ 0xf325b993, "seq_printf" },
	{ 0x8442f2b8, "pci_find_next_ext_capability" },
	{ 0x90089d0c, "pci_disable_sriov" },
	{ 0x12a4e128, "__arch_copy_from_user" },
	{ 0x4d6a9a31, "set_page_dirty_lock" },
	{ 0x69eabd0c, "single_release" },
	{ 0xa65c6def, "alt_cb_patch_nops" },
	{ 0xcb7555c5, "dma_set_mask" },
	{ 0xd1b7caa8, "sched_set_fifo" },
	{ 0x62e55312, "dma_unmap_sg_attrs" },
	{ 0x8661fb81, "pcim_iomap_table" },
	{ 0x8e75b35b, "pci_read_config_byte" },
	{ 0x7aa1756e, "kvfree" },
	{ 0x897e51b3, "single_open" },
	{ 0x170f1634, "pcim_enable_device" },
	{ 0x7a0194b, "__pm_runtime_disable" },
	{ 0x65ffdb18, "debugfs_create_dir" },
	{ 0xb5b54b34, "_raw_spin_unlock" },
	{ 0xa1be85d3, "pci_free_irq_vectors" },
	{ 0xc68504d7, "__kvmalloc_node_noprof" },
	{ 0x5cbb604f, "pci_enable_sriov" },
	{ 0x104904d, "__pm_runtime_idle" },
	{ 0x19d2101e, "cdev_init" },
	{ 0x9ec38f1b, "kmalloc_caches" },
	{ 0xbf4c8251, "vchan_find_desc" },
	{ 0x1a77ef70, "cdev_del" },
	{ 0x85b902d2, "kmem_cache_destroy" },
	{ 0x99cb3692, "vchan_tx_submit" },
	{ 0x814ddf6f, "dma_map_sg_attrs" },
	{ 0x9bfa25dd, "module_layout" },
};

MODULE_INFO(depends, "");

MODULE_ALIAS("pci:v00001FF4d00000000sv*sd*bc*sc*i*");
MODULE_ALIAS("pci:v00001FF4d00000001sv*sd*bc*sc*i*");

MODULE_INFO(srcversion, "6ADE83EA0EC837B92FDA9AD");
